Description Usage Arguments Examples
View source: R/script - Axomatic.r
Simplified function for defining the x axis with settings for tickmarks and labels. The function is used as a ggplot object.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 |
from |
Start of the axis. |
to |
End of the axis. |
ticks |
How much space between each tickmark. |
labels |
The numbers or text beneath the tickmarks. 0 = no labels, 1 = label on every tickmark, 5 = label every 5'th tickmark, and so on. Setting this paramter as a vector lets you make self-defined labels, e.g. you can write c("one","two","three","four") or whatever. |
pad |
How much space before and after the first and last mark on the axis. |
upperPad |
specification of pad, but only for space after the last mark. |
lowerPad |
specifiction of pad, but only for spcae before the first mark. |
trans_labels |
"none": Does nothing (default). Lognatural: Transforms numerical labels back to non-logarithmic form if the axis data is log transformed |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.