Description Usage Arguments Examples
View source: R/script - Axomatic.r
Used for defining x axis, y axis, and plot shape (square, rectangular, etc) It uses functions axis_x() and axis_y() to make two axes, and then lets the user specify the shape of the plot. The function is used and added as a ggplot object. See help page for axis_x() and axis_y().
1 | axomatic(x, y, ratio = 1, scaleSize = T)
|
x |
an x-axis specified with the function axis_x |
y |
an y-axis specified with the function axis_y |
ratio |
the ratio between the x and y axis. Defaults to 1 (a square) |
scaleSize |
if the ratio is for physical graph size (T, default) or the values displayed. If physical (T), setting ration to 1 will always result in a square graph. If not physical (F), setting ration to 1 will give equal scale on both axes. |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.